/**
  ******************************************************************************
  * @file rtc.h
  * @brief This file includes the basic setting for RTC software
  * @author STMicroelectronics - MCD Application Team
  * @version V1.1.1
  * @date 23/11/2009
  ******************************************************************************
  *
  */

// User defines ---------------------------------------------------------------
// next line controls the mode of keeping real time field actual (continuous or on request)
//#define KEEP_RT									

// next line controls the fmaster clock while LS is measured (HSE or HSI)
#define MEASURE_ON_HSE

// Define to prevent recursive inclusion -------------------------------------
#ifndef __RTC_H
#define __RTC_H

// Exported constants --------------------------------------------------------
#define SECONDS_IN_A_DAY 		((u32)(24)*60*60)
#define SECONDS_IN_A_HOUR 		(60*60)
#define SECONDS_IN_A_MINUTE 	60

// Exported types ------------------------------------------------------------
typedef struct {									// real time information field structure
	u8 second;
	u8 minute;
	u8 hour;
	u8 day;
} st_time;
														//  external pulses counting structures
typedef struct {
	u16 edge_second_counter;      // counter for one second interval
	u16 second_overflow_counter;  // register of one second intervals elapsed
	u32 edge_day_counter;         // counter for one day interval
	u16 day_overflow_counter;     // register of one day intervals elapsed
} st_fx_time;

// Exported variables --------------------------------------------------------
extern	st_fx_time fx_time;		// variable for time keeping	
extern	u16 beep_fqcy;				// variable for beep frequency measured value
extern	u32  edge_day_overflow_limit;	// compare limit for one day interval

#endif



